@@ -18,7 +18,7 @@
 #define JPEG_INTERNALS
 #include "jinclude.h"
 #include "jpeglib.h"
-#include "jstdhuff.c"
+#include "jstdhuff.h"
 
 
 /*
